import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayTopPages(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopPages, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisTopPages']

    def hook(self):
        display = self.iwla.getDisplay()
        top_pages = self.iwla.getMonthStats()['top_pages']
        top_pages = sorted(top_pages.items(), key=lambda t: t[1], reverse=True)

        # All in a page
        title = time.strftime('All Pages - %B %Y', self.iwla.getCurTime())
        filename = 'top_pages.html'
        path = self.iwla.getCurDisplayPath(filename)

        page = display.createPage(title, path, self.iwla.getConfValue('css_path', []))
        table = display.createBlock(DisplayHTMLBlockTable, 'All Pages', ['URI', 'Entrance'])
        table.setColsCSSClass(['', 'iwla_hit'])
        total_hits = [0]*2        
        for (uri, entrance) in top_pages:
            table.appendRow([generateHTMLLink(uri), entrance])
            total_hits[1] += entrance
        page.appendBlock(table)
                        
        display.addPage(page)

        link = '<a href=\'%s\'>All pages</a>' % (filename)
        title = '%s - %s' % ('Top Pages', link)

        # Top in index
        index = self.iwla.getDisplayIndex()
        
        table = display.createBlock(DisplayHTMLBlockTable, title, ['URI', 'Entrance'])
        table.setColsCSSClass(['', 'iwla_hit'])
        for (uri, entrance) in top_pages[:10]:
            table.appendRow([generateHTMLLink(uri), entrance])
            total_hits[1] -= entrance
        if total_hits[1]:
            total_hits[0] = 'Others'
            table.appendRow(total_hits)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')
        index.appendBlock(table)
